==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/InputGroupItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let InputGroupItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class InputGroupItemDescriptionMetadata extends Base {
        static b(a) {
            if (InputGroupItemDescriptionMetadata.a == null) {
                InputGroupItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                InputGroupItemDescriptionMetadata.c(InputGroupItemDescriptionMetadata.a);
            }
            if (a.j(InputGroupItemDescriptionMetadata.a)) {
                return;
            }
            a.y(InputGroupItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:XInputGroupItem");
            a.item("Name", "String");
        }
        static d(a) {
            InputGroupItemDescriptionMetadata.b(a);
            a.z("InputGroupItem", InputGroupItemDescriptionMetadata.a);
        }
    }
    InputGroupItemDescriptionMetadata.$t = /*@__PURE__*/ markType(InputGroupItemDescriptionMetadata, 'InputGroupItemDescriptionMetadata');
    InputGroupItemDescriptionMetadata.a = null;
    return InputGroupItemDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/InputGroupItemDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
/**
 * @hidden
 */
export let InputGroupItemDescriptionMetadata = /*@__PURE__*/ (() => {
    class InputGroupItemDescriptionMetadata extends Base {
        static b(a) {
            if (InputGroupItemDescriptionMetadata.a == null) {
                InputGroupItemDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                InputGroupItemDescriptionMetadata.c(InputGroupItemDescriptionMetadata.a);
            }
            if (a.k(InputGroupItemDescriptionMetadata.a)) {
                return;
            }
            a.aa(InputGroupItemDescriptionMetadata.a);
        }
        static c(a) {
            a.item("__qualifiedNameTS", "String:XInputGroupItem");
            a.item("Name", "String");
        }
        static d(a) {
            InputGroupItemDescriptionMetadata.b(a);
            a.ab("InputGroupItem", InputGroupItemDescriptionMetadata.a);
        }
    }
    InputGroupItemDescriptionMetadata.$t = /*@__PURE__*/ markType(InputGroupItemDescriptionMetadata, 'InputGroupItemDescriptionMetadata');
    InputGroupItemDescriptionMetadata.a = null;
    return InputGroupItemDescriptionMetadata;
})();
